@@ -1,13 +1,17 @@
+use crate::config::Config;
+use crate::icons;
 use crate::util::StatefulList;
-use crate::{config::Config, icons};
 use path_absolutize::Absolutize;
 use std::collections::HashSet;
+use std::iter;
 use std::path::Path;
 use std::path::PathBuf;
 use tui::{
   buffer::Buffer,
   layout::Rect,
   style::{Color, Modifier, Style},
+  text::Span,
+  text::Spans,
   widgets::List,
   widgets::ListItem,
   widgets::StatefulWidget,
@@ -21,7 +25,9 @@ pub struct ExpandedPaths {
 
 impl ExpandedPaths {
   pub fn extend(&mut self, x: &ExpandedPaths) {
-    self.expanded_paths.extend(x.expanded_paths.iter().map(|x| x.clone()));
+    self
+      .expanded_paths
+      .extend(x.expanded_paths.iter().map(|x| x.clone()));
   }
 
   pub fn toggle_expanded(&mut self, path: &Path) {
@@ -167,15 +173,17 @@ impl FileTreeState {
   }
 }
 
-pub struct FileTree {}
+pub struct FileTree<'a> {
+	cfg: &'a Config
+}
 
-impl FileTree {
-  pub fn new() -> FileTree {
-    FileTree {}
+impl<'a> FileTree<'a> {
+  pub fn new(cfg: &'a Config) -> FileTree {
+    FileTree { cfg }
   }
 }
 
-impl StatefulWidget for FileTree {
+impl<'a> StatefulWidget for FileTree<'a> {
   type State = FileTreeState;
 
   fn render(self, area: Rect, buf: &mut Buffer, state: &mut Self::State) {
@@ -183,15 +191,10 @@ impl StatefulWidget for FileTree {
       .lines
       .items
       .iter()
-      .map(|tel| ListItem::new("  ".repeat(tel.level) + tel.line.as_str()))
+      .map(|x| x.make_line())
       .collect();
     let list = List::new(items)
-      .style(Style::default().fg(Color::White))
-      .highlight_style(
-        Style::default()
-          .bg(Color::LightBlue)
-          .add_modifier(Modifier::BOLD),
-      );
+      .highlight_style(self.cfg.highlight_style);
     list.render(area, buf, &mut state.lines.state);
   }
 }
@@ -209,10 +212,20 @@ pub struct TreeEntry {
 /// Identified by `path` which is used to locate the matching
 pub struct TreeEntryLine {
   pub path: PathBuf,
-  pub line: String,
+  pub line: Vec<(String, Style)>,
   pub level: usize,
 }
 
+impl TreeEntryLine {
+  fn make_line(&self) -> ListItem {
+    ListItem::new(Spans(
+      iter::once(Span::styled("  ".repeat(self.level), self.line.first().map(|(_, s)| s.clone()).unwrap_or(Style::default())))
+        .chain(self.line.iter().map(|(x, s)| Span::styled(x, s.clone())))
+        .collect(),
+    )).style(self.line.last().map(|(_, s)| s.clone()).unwrap_or(Style::default()))
+  }
+}
+
 impl TreeEntry {
   fn new(path: PathBuf) -> TreeEntry {
     let path = path
@@ -285,19 +298,19 @@ impl TreeEntry {
     } else {
       if self.is_dir {
         if self.expanded {
-          ''
+          ''
         } else {
           if self.is_link {
             ''
           } else {
-            ''
+            ''
           }
         }
       } else {
         if self.is_link {
           ''
         } else {
-          ''
+          ''
         }
       }
     }
@@ -321,9 +334,14 @@ impl TreeEntry {
         };
         format!("{} {} ", arrow, icon)
       };
+      let mainstyle = if self.is_dir {
+      	conf.dir_name_style
+      } else {
+        conf.file_name_style
+      };
       TreeEntryLine {
         path: self.path.clone(),
-        line: format!("{} {}", prefix, name),
+        line: vec![(prefix, conf.icon_style), (" ".to_string() + name, mainstyle)],
         level,
       }
     })
